@@ -1,4 +1,3 @@
-
 #' Retrieves the assignment groups within a course.
 #'
 #' This function retrieves the assignment groups within a specific course in the Canvas LMS API.
@@ -17,15 +16,16 @@ get_assignment_groups <- function(canvas, course_id, per_page = 100) {
   # Make the API request
   response <- httr::GET(url, httr::add_headers(Authorization = paste("Bearer", canvas$api_key)))
 
-  # Check the response status code
-  if (httr::status_code(response) != 200) {
-    stop("Failed to retrieve assignment groups. Please check your authentication and API endpoint.")
-  }
+  # Use pagination helper to get all pages
+  responses <- paginate(response, canvas$api_key)
 
-  # Parse the response as JSON
-  assignment_groups <- httr::content(response, "text", encoding = "UTF-8") %>%
-    jsonlite::fromJSON(flatten = TRUE) %>%
-    as.data.frame() %>%
+  # Parse and combine all results
+  assignment_groups_list <- lapply(responses, function(resp) {
+    httr::content(resp, "text", encoding = "UTF-8") %>%
+      jsonlite::fromJSON(flatten = TRUE) %>%
+      as.data.frame()
+  })
+  assignment_groups <- dplyr::bind_rows(assignment_groups_list) %>%
     dplyr::mutate(course_id = course_id)
 
   # Return the list of assignment groups
