@@ -14,8 +14,10 @@ get_section_information <- function(canvas, course_id, section_id) {
   url <- paste0(canvas$base_url, "/api/v1/courses/", course_id, "/sections/", section_id)
 
   # Make the API request
-  response <- httr::GET(url,
-                        httr::add_headers(Authorization = paste("Bearer", canvas$api_key)))
+  response <- httr::GET(
+    url,
+    httr::add_headers(Authorization = paste("Bearer", canvas$api_key))
+  )
 
   # Check the response status code
   if (httr::status_code(response) != 200) {
